use crate::rocket::futures::TryFutureExt;
use serde::Serialize;
use serde_json::json;
use slack_api;
use std::env;

#[derive(Debug, Serialize)]
struct SlackProfile<'a> {
    status_text: &'a str,
    status_emoji: &'a str,
    status_expiration: i32,
}

pub async fn set_status(msg: &str) -> Result<(), String> {
    let client = slack_api::default_client().map_err(|e| e.to_string())?;
    let api_key = env::var("SLACK_OAUTH_ACCESS_TOKEN").expect("SLACK_OAUTH_ACCESS_TOKEN");
    let profile = SlackProfile {
        status_text: msg,
        status_emoji: ":mountain:",
        status_expiration: 0,
    };
    let encoded_profile = json!(profile).to_string();
    let set_req = slack_api::users_profile::SetRequest {
        user: None,
        profile: Some(&encoded_profile),
        name: None,
        value: None,
    };

    slack_api::users_profile::set(&client, &api_key, &set_req)
        .map_err(|e| e.to_string())
        .await?;

    Ok(())
}

pub async fn update_all() -> Result<(), String> {
    let client = slack_api::default_client().map_err(|e| e.to_string())?;
    let api_key = env::var("SLACK_OAUTH_ACCESS_TOKEN").expect("SLACK_OAUTH_ACCESS_TOKEN");
    let list_req = slack_api::users::ListRequest::default();
    let resp = slack_api::users::list(&client, &api_key, &list_req)
        .map_err(|e| e.to_string())
        .await?;

    let members = resp.members.unwrap();
    println!("Got vec with {} members", members.len());

    Ok(())
}
